Module: Haml

Defined in:
lib/haml/filters/php.rb

Overview

A PHP Filter for Haml. This simply wraps code inside tags. While this may seem like a strange idea, some people use Haml to generate mostly static HTML documents that then include small amounts of PHP.

This code also serves as an example of how to implement a simple filter for Haml.

Defined Under Namespace

Modules: Filters